@@ -29,6 +29,8 @@ class PipeType(Enum):
     CROSS_OVER = "Cross Over"
     TOE_SLEEVE = "Toe Sleeve"
     CASING_JOINTS = "Casing Joints"
+    DV_TOOL = "Differential Valve Tool"
+    ACP = "Annular Casing Packer"
 
     @staticmethod
     def determine_type(family: str):
@@ -48,7 +50,9 @@ class PipeType(Enum):
             'float_shoe': PipeType.FLOAT_SHOE,
             'cross_over': PipeType.CROSS_OVER,
             'toe_sleeve': PipeType.TOE_SLEEVE,
-            'casing_joints': PipeType.CASING_JOINTS
+            'casing_joints': PipeType.CASING_JOINTS,
+            'dv_tool': PipeType.DV_TOOL,
+            'acp': PipeType.ACP
         }
         _type = mapping.get(family)
         if not _type:
