@@ -109,7 +109,9 @@ class Hole(SectionsMixin):
         :param hole_depth: a wits dict or actual hole depth
         :return: if any update occurred or not
         """
-        if self[-1].hole_type != HoleType.OPEN_HOLE:
+
+        # If there are no sections in the hole or the last hole is Open Hole, do not update hole and return
+        if not self or self[-1].hole_type != HoleType.OPEN_HOLE:
             return False
 
         if isinstance(hole_depth, dict):
